.. _contents:

PyGuitarPro
===========

PyGuitarPro is a package to read, write and manipulate GP3, GP4 and GP5 files. Initially PyGuitarPro is a Python port
of `AlphaTab <https://www.alphatab.net/>`_ which is a Haxe port of `TuxGuitar <https://tuxguitar.herac.com.ar/>`_.

To anyone wanting to create their own the best guitar tablature editor in Python this package will be the good thing to
start with.

.. toctree::
   :maxdepth: 2

   pyguitarpro/install
   pyguitarpro/quickstart
   pyguitarpro/api
   pyguitarpro/format


Indices and tables
==================

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`

.. vim: tw=120 cc=121
